@@ -274,9 +274,8 @@ class FileStoreMetadata:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         metadata = FileStoreMetadata_pb2.FileStoreMetadata()
-        metadata.ParseFromString(byte_array)
+        metadata.ParseFromString(serialized)
         self._read_proto_object(metadata)
 
     def _read_proto_object(self, metadata: FileStoreMetadata_pb2.FileStoreMetadata):
@@ -563,9 +562,8 @@ class FileMetadata:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         metadata = FileMetadata_pb2.FileMetadata()
-        metadata.ParseFromString(byte_array)
+        metadata.ParseFromString(serialized)
         self._read_proto_object(metadata)
 
     def _read_proto_object(self,
@@ -806,9 +804,8 @@ class FileStoreMetadataRequest:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         request = FileStoreMetadataRequest_pb2.FileStoreMetadataRequest()
-        request.ParseFromString(byte_array)
+        request.ParseFromString(serialized)
         self._read_proto_object(request)
 
     def _read_proto_object(self, metadata_request: FileStoreMetadataRequest_pb2.FileStoreMetadataRequest):
@@ -960,9 +957,8 @@ class FileStoreMetadataResponse:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         response = FileStoreMetadataResponse_pb2.FileStoreMetadataResponse()
-        response.ParseFromString(byte_array)
+        response.ParseFromString(serialized)
         self._read_proto_object(response)
 
     def _read_proto_object(self,
@@ -1173,9 +1169,8 @@ class FileStoreRequest:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         request = FileStoreRequest_pb2.FileStoreRequest()
-        request.ParseFromString(byte_array)
+        request.ParseFromString(serialized)
         self._read_proto_object(request)
 
     def _read_proto_object(self, request: FileStoreRequest_pb2.FileStoreRequest):
@@ -1351,9 +1346,8 @@ class FileStoreResponse:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         response = FileStoreResponse_pb2.FileStoreResponse()
-        response.ParseFromString(byte_array)
+        response.ParseFromString(serialized)
         self._read_proto_object(response)
 
     def _read_proto_object(self,
@@ -1569,9 +1563,8 @@ class FileMetadataRequest:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         request = FileMetadataRequest_pb2.FileMetadataRequest()
-        request.ParseFromString(byte_array)
+        request.ParseFromString(serialized)
         self._read_proto_object(request)
 
     def _read_proto_object(self,
@@ -1741,9 +1734,8 @@ class FileMetadataResponse:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         response = FileMetadataResponse_pb2.FileMetadataResponse()
-        response.ParseFromString(byte_array)
+        response.ParseFromString(serialized)
         self._read_proto_object(response)
 
     def _read_proto_object(self,
